RDFCalendar.Format

Package RDFCalendar :: Module Format |
[show private | hide private]
[frames | no frames]

## Module RDFCalendar.Format

    Constants for parsing and writing.

    Copyright (C) 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

Function Summary
| ``get_property_label`(property_name)` Return the special property label for the given 'property_name', or None if a generic label is to be used (for example, to construct a predicate for RDF triple stores).

Variable Summary
`list` | `all_labels` = `['class', 'completed', 'created', 'descript...`
`tuple` | `connector_attributes` = `('RELATED-TO',)`
`list` | `connector_labels` = `['related-to', 'organizer', 'attendee...`
`tuple` | `datetime_attributes` = `('COMPLETED', 'CREATED', 'DTSTAMP'...`
`tuple` | `datetime_values` = `('UNTIL',)`
`dict` | `element_names` = `{'VTODO': 'to-do', 'VCALENDAR': 'calenda...`
`dict` | `item_type_names` = `{'to-do': 'VTODO', 'journal': 'VJOURNA...`
`tuple` | `multivalue_attributes` = `('RDATE', 'EXDATE')`
`dict` | `permitted_attributes` = `{'VTODO': ('CLASS', 'COMPLETED', ...`
`dict` | `permitted_elements` = `{'VTODO': ('VALARM',), 'VCALENDAR':...`
`dict` | `permitted_labels` = `{'dtstamp': 'datetime', 'created': 'd...`
`tuple` | `person_attributes` = `('ATTENDEE', 'ORGANIZER')`
`str` | `rdfcalendar` = `'http://www.boddie.org.uk/ns/rdfcalendar/'...`
`str` | `rdftype` = `'http://www.w3.org/1999/02/22-rdf-syntax-ns#ty...`
`tuple` | `subvalue_attributes` = `('RRULE', 'EXRULE')`
`list` | `supported_item_types` = `['card', 'calendar', 'event', 'fr...`
`list` | `uriref_labels` = `['uri', 'related-to']`
`list` | `value_labels` = `['start', 'duration', 'end', 'datetime', ...`

Function Details

### get_property_label(property_name)
    Return the special property label for the given 'property_name', or None
    if a generic label is to be used (for example, to construct a predicate for
    RDF triple stores).

Variable Details

    ### all_labels Type: `list` Value:
        ['class',
         'completed',
         'created',
         'description',
         'dtstamp',
         'dtstart',
         'geo',
         'last-modified',
        ...

    ### connector_attributes Type: `tuple` Value:
        ('RELATED-TO',)

    ### connector_labels Type: `list` Value:
        ['related-to', 'organizer', 'attendee']

    ### datetime_attributes Type: `tuple` Value:
        ('COMPLETED', 'CREATED', 'DTSTAMP', 'DTSTART', 'DTEND', 'DUE', 'LAST-M\
        ODIFIED')

    ### datetime_values Type: `tuple` Value:
        ('UNTIL',)

    ### element_names Type: `dict` Value:
        {'VALARM': 'alarm',
         'VCALENDAR': 'calendar',
         'VCARD': 'card',
         'VEVENT': 'event',
         'VFREEBUSY': 'free-busy',
         'VJOURNAL': 'journal',
         'VTIMEZONE': 'timezone',
         'VTODO': 'to-do'}

    ### item_type_names Type: `dict` Value:
        {'alarm': 'VALARM',
         'calendar': 'VCALENDAR',
         'card': 'VCARD',
         'event': 'VEVENT',
         'free-busy': 'VFREEBUSY',
         'journal': 'VJOURNAL',
         'timezone': 'VTIMEZONE',
         'to-do': 'VTODO'}

    ### multivalue_attributes Type: `tuple` Value:
        ('RDATE', 'EXDATE')

    ### permitted_attributes Type: `dict` Value:
        {'VALARM': ('ACTION',
                    'TRIGGER',
                    'DURATION',
                    'REPEAT',
                    'DESCRIPTION',
                    'ATTACH',
                    'ATTENDEE'),
         'VCALENDAR': ('VERSION', 'CALSCALE', 'METHOD', 'PRODID'),
        ...

    ### permitted_elements Type: `dict` Value:
        {'VALARM': (),
         'VCALENDAR': ('VEVENT', 'VTODO', 'VJOURNAL', 'VFREEBUSY', 'VTIMEZONE'\
        ),
         'VCARD': (),
         'VEVENT': ('VALARM',),
         'VFREEBUSY': (),
         'VJOURNAL': (),
         'VTIMEZONE': (),
        ...

    ### permitted_labels Type: `dict` Value:
        {'attendee': 'uri',
         'completed': 'datetime',
         'created': 'datetime',
         'dtend': 'datetime',
         'dtstamp': 'datetime',
         'dtstart': 'datetime',
         'due': 'datetime',
         'last-modified': 'datetime',
        ...

    ### person_attributes Type: `tuple` Value:
        ('ATTENDEE', 'ORGANIZER')

    ### rdfcalendar Type: `str` Value:
        'http://www.boddie.org.uk/ns/rdfcalendar/'

    ### rdftype Type: `str` Value:
        'http://www.w3.org/1999/02/22-rdf-syntax-ns#type'

    ### subvalue_attributes Type: `tuple` Value:
        ('RRULE', 'EXRULE')

    ### supported_item_types Type: `list` Value:
        ['card', 'calendar', 'event', 'free-busy', 'to-do', 'journal']

    ### uriref_labels Type: `list` Value:
        ['uri', 'related-to']

    ### value_labels Type: `list` Value:
        ['start',
         'duration',
         'end',
         'datetime',
         'uri',
         'details',
         'related-to',
         'contains',
        ...

Generated by Epydoc 2.1 on Mon Mar 19 01:08:11 2007 | http://epydoc.sf.net